API
===

.. toctree::
    :maxdepth: 4

.. automodule:: uranography.spheremap
    :members: SphereMap
    :exclude-members: add_patches, healpix_cmap, healpix_data, healpix_glyph, healpix_renderer, star_data_source
    :show-inheritance:

.. automodule:: uranography.mollweide
    :members: MollweideMap
    :show-inheritance:

.. automodule:: uranography.horizon
    :members: HorizonMap
    :show-inheritance:

.. automodule:: uranography.planisphere
    :members: Planisphere
    :show-inheritance:

.. automodule:: uranography.armillary
    :members: ArmillarySphere
    :show-inheritance:

.. automodule:: uranography.camera
    :members:

.. automodule:: uranography.stars
    :members:
